@@ -107,6 +107,9 @@ static void resize_container(gContainer *cont, int w, int h)
 	/*w += cont->width() - cont->containerWidth();
 	h += cont->height() - cont->containerHeight();*/
 	
+	if (cont->isWindow())
+		h += cont->height() - cont->containerHeight();
+
 	if (w >= 0 && h >= 0)
 		cont->resize(w, h);
 }
@@ -122,6 +125,7 @@ static void resize_container(gContainer *cont, int w, int h)
 #define IS_EXPAND(_object) (((gControl*)_object)->isExpand())
 #define IS_IGNORE(_object) (((gControl*)_object)->isIgnore())
 #define IS_DESIGN(_object) (((gControl*)_object)->isDesign())
+#define IS_USER(_object) (((gContainer *)_object)->isUser())
 #define IS_WIDGET_VISIBLE(_widget)  (((gControl*)_widget)->isVisible())
 
 #define CAN_ARRANGE(_object) (((gContainer *)_object)->isShown() && !((gControl *)_object)->isDestroyed())
@@ -293,6 +297,7 @@ void gContainer::initialize()
 	_no_arrangement = 0;
 	_did_arrangement = false;
 	_is_container = true;
+	_user = false;
 	_user_container = false;
 	_shown = false;
 	_arrange_later = false;
@@ -302,12 +307,10 @@ void gContainer::initialize()
 	arrangement.padding = 0;
 	arrangement.autoresize = false;
 	arrangement.locked = false;
-	arrangement.user = false;
 	arrangement.margin = false;
 	arrangement.indent = false;
 	arrangement.centered = false;
 	arrangement.invert = false;
-	arrangement.paint = false;
 }
 
 gContainer::gContainer() 
@@ -440,17 +443,9 @@ void gContainer::setAutoResize(bool vl)
 
 void gContainer::setUser()
 {
-	if (arrangement.user)
-		return;
-	
-	arrangement.user = true;
+	_user = true;
 	performArrange();
 	updateDesignChildren();
-}
-
-void gContainer::setPaint()
-{
-	arrangement.paint = true;
 	ON_DRAW_BEFORE(border, this, cb_expose, cb_draw);
 }
 
@@ -781,7 +776,7 @@ bool gContainer::resize(int w, int h, bool no_decide)
 	_client_w = 0;
 	_client_h = 0;
 	
-	if (arrangement.paint)
+	if (isUser())
 		CUSERCONTROL_cb_resize(this);
 
 	performArrange();
@@ -831,7 +826,7 @@ void gContainer::updateFont()
 	for (i = 0; i < childCount(); i++)
 		child(i)->updateFont();
 
-	if (arrangement.paint)
+	if (isUser())
 		CUSERCONTROL_cb_font(this);
 }
 
