@@ -37,18 +37,16 @@ void CUSERCONTROL_cb_resize(gContainer *sender);
 struct gContainerArrangement
 {
 	unsigned mode : 4;
-	unsigned user : 1;
 	unsigned locked : 1;
+	unsigned dirty : 1;
 	unsigned margin : 1;
 	unsigned spacing : 1;
 	unsigned padding : 8;
 	unsigned indent : 1;
 	unsigned centered : 1;
-	unsigned dirty : 1;
 	unsigned autoresize : 1;
 	unsigned invert : 1;
-	unsigned paint : 1;
-	unsigned _reserved: 10;
+	unsigned _reserved: 12;
 }; 
 
 class gContainer : public gControl
@@ -60,14 +58,12 @@ public:
 
 	int arrange() const { return arrangement.mode; }
 	bool autoResize() const { return arrangement.autoresize; }
-	bool isUser() const { return arrangement.user; }
 	int padding() const { return arrangement.padding; }
 	bool spacing() const { return arrangement.spacing; }
 	bool margin() const { return arrangement.margin; }
 	bool indent() const { return arrangement.indent; }
 	bool invert() const { return arrangement.invert; }
 	bool centered() const { return arrangement.centered; }
-	bool isPaint() const { return arrangement.paint; }
 	bool isArranging() const { return arrangement.locked; }
 	
 	virtual int clientWidth();
@@ -80,8 +76,6 @@ public:
 	virtual int containerHeight();
 
 	void setArrange(int vl);
-	void setUser();
-	void setPaint();
 	void setAutoResize(bool vl);
 	void setPadding(int vl);
 	void setSpacing(bool vl);
@@ -90,6 +84,9 @@ public:
 	void setInvert(bool vl);
 	void setCentered(bool vl);
 
+	void setUser();
+	bool isUser() const { return _user; }
+
 	void setUserContainer() { _user_container = true; }
 	bool isUserContainer() const { return _user_container; }
 	
@@ -171,6 +168,7 @@ private:
   gContainer *_proxyContainer;
   gContainer *_proxyContainerFor;
 	unsigned _did_arrangement : 1;
+	unsigned _user : 1;
 	unsigned _user_container : 1;
 	unsigned _shown : 1;
 	unsigned _arrange_later : 1;
