@@ -36,8 +36,7 @@ static void cb_change(GtkRange *wid, gSlider *data)
 		return;
 	
 	data->_value = new_value;
-	if (data->onChange) 
-		data->onChange(data);
+	CB_slider_change(data);
 }
 
 void gSlider::update()
@@ -76,7 +75,6 @@ void gSlider::init()
 	//GtkAdjustment* adj = gtk_range_get_adjustment(GTK_RANGE(widget));
 
 	_use_wheel = true;
-	onChange = NULL;
 
 	g_signal_connect(widget, "value-changed", G_CALLBACK(cb_change), (gpointer)this);
 	//g_signal_connect(adj, "changed", G_CALLBACK(cb_change), (gpointer)this);
@@ -224,43 +222,9 @@ void gSlider::setValue(int vl)
 	_value = vl;
 	update();
 	
-	emit(SIGNAL(onChange));
+	CB_slider_change(this);
 }
 
-#if 0
-void gSlider::orientation(int w,int h)
-{
-	//GtkAdjustment *adj;
-	//GtkOrientation orient;
-	
-	gtk_orientable_set_orientation(GTK_ORIENTABLE(widget),  (w < h) ? GTK_ORIENTATION_VERTICAL : GTK_ORIENTATION_HORIZONTAL);
-
-	/*if (orient != gtk_orientable_get_orientation(GTK_ORIENTABLE(widget)))
-	{
-		adj = gtk_range_get_adjustment(GTK_RANGE(widget));
-		g_object_ref(adj);
-		
-		gtk_widget_destroy(widget);
-		
-		widget = gtk_scale_new(
-		if (type == GTK_TYPE_VSCALE)
-			widget = gtk_vscale_new(adj);
-		else
-			widget = gtk_hscale_new(adj);
-		
-		gtk_container_add(GTK_CONTAINER(border), widget);
-		
-		gtk_scale_set_draw_value(GTK_SCALE(widget), false);
-		gtk_widget_show(widget);
-		widgetSignals();
-		g_signal_connect(G_OBJECT(widget), "value-changed", G_CALLBACK(cb_change), (gpointer)this);
-		
-		g_object_unref(adj);
-		
-		init();
-	}*/
-}
-#endif
 
 void gSlider::applyOrientation(GtkOrientation orientation)
 {
