@@ -2,7 +2,7 @@
 
   CContainer.cpp
 
-  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@
 #include "CConst.h"
 #include "CTabStrip.h"
 #include "CColor.h"
-
+#include "cpaint_impl.h"
 #include "CContainer.h"
 
 #if QT5
@@ -55,6 +55,31 @@
 //#define DEBUG_ME
 //#define USE_CACHE 1
 
+#define CALL_FUNCTION(_this, _func) \
+{ \
+	if ((_this)->func._func) \
+	{ \
+		GB_FUNCTION func; \
+		func.object = (_this); \
+		func.index = (_this)->func._func; \
+		GB.Call(&func, 0, TRUE); \
+	} \
+}
+
+static void send_change_event(CWIDGET *_object)
+{
+	if (GB.Is(THIS, CLASS_Container) && THIS->widget.flag.user)
+		CALL_FUNCTION(THIS_USERCONTROL, change);
+}
+
+void CUSERCONTROL_send_change_event()
+{
+	CWidget::each(send_change_event);
+}
+
+
+//-------------------------------------------------------------------------
+
 DECLARE_EVENT(EVENT_Insert);
 //DECLARE_EVENT(EVENT_Remove);
 DECLARE_EVENT(EVENT_BeforeArrange);
@@ -238,7 +263,7 @@ static void resize_container(void *_object, QWidget *cont, int w, int h)
 	#if USE_CACHE
 	resize_widget(_object, w + wid->width() - cont->width(), h + wid->height() - cont->height());
 	#else
-	CWIDGET_resize(_object, w + wid->width() - cont->width(), h + wid->height() - cont->height());
+	CWIDGET_auto_resize(_object, w + wid->width() - cont->width(), h + wid->height() - cont->height());
 	#endif
 }
 
@@ -247,18 +272,18 @@ static void resize_container(void *_object, QWidget *cont, int w, int h)
 #define CONTAINER_TYPE QWidget *
 #define ARRANGEMENT_TYPE CCONTAINER_ARRANGEMENT *
 
-#define IS_RIGHT_TO_LEFT() qApp->isRightToLeft()
-
 #define GET_WIDGET(_object) ((CWIDGET *)_object)->widget
+#define IS_RIGHT_TO_LEFT(_object) (((CWIDGET *)_object)->widget)->isRightToLeft()
 #define GET_CONTAINER(_object) ((CCONTAINER *)_object)->container
 #define GET_ARRANGEMENT(_object) ((CCONTAINER_ARRANGEMENT *)_object)
 #define IS_EXPAND(_object) (((CWIDGET *)_object)->flag.expand)
 #define IS_IGNORE(_object) (((CWIDGET *)_object)->flag.ignore)
-#define IS_DESIGN(_object) (CWIDGET_test_flag(_object, WF_DESIGN) && CWIDGET_test_flag(_object, WF_DESIGN_LEADER))
+#define IS_DESIGN(_object) (CWIDGET_is_design(_object))
+#define IS_USER(_object) (((CWIDGET *)_object)->flag.user)
 //#define IS_WIDGET_VISIBLE(_widget) (_widget)->isVisible()
 
 //#define CAN_ARRANGE(_object) ((_object) && !CWIDGET_test_flag(_object, WF_DELETED) && (!GB.Is(_object, CLASS_Window) || (((CWINDOW *)_object)->opened)))
-#define CAN_ARRANGE(_object) ((_object) && ((CWIDGET *)(_object))->flag.shown && !CWIDGET_test_flag(_object, WF_DELETED))
+#define CAN_ARRANGE(_object) ((_object) && ((CWIDGET *)(_object))->flag.shown && !((CWIDGET *)(_object))->flag.deleted)
 
 #if USE_CACHE
 
@@ -325,8 +350,8 @@ void CCONTAINER_arrange(void *_object)
 	#if DEBUG_CONTAINER
 	static int level = 0;
 	
-	if (!level)
-		_count_move = _count_resize = _count_set_geom = 0;
+	//if (!level)
+	//	_count_move = _count_resize = _count_set_geom = 0;
 	level++;
 	#endif
 
@@ -335,11 +360,19 @@ void CCONTAINER_arrange(void *_object)
 	_cache_level++;
 	#endif
 
+	/*for (int i = 1; i < level; i++)
+		fputs("  ", stderr);
+	fprintf(stderr, "CCONTAINER_arrange: [%d], %s: %d %d / %d x %d\n", level, THIS->widget.name, WIDGET->x(), WIDGET->y(), WIDGET->width(), WIDGET->height());*/
+	
 	if (GB.Is(THIS, CLASS_TabStrip))
 		CTABSTRIP_arrange(THIS);
 
 	CCONTAINER_arrange_real(_object);
 	
+	/*for (int i = 1; i < level; i++)
+		fputs("  ", stderr);
+	fprintf(stderr, "CCONTAINER_arrange: [%d], %s: <<<<<<<<\n", level, THIS->widget.name);*/
+
 	#if USE_CACHE
 	_cache_level--;
 	
@@ -355,11 +388,11 @@ void CCONTAINER_arrange(void *_object)
 
 	#if DEBUG_CONTAINER
 	level--;
-	if (!level)
+	/*if (!level)
 	{
 		if (_count_move || _count_resize || _count_set_geom)
 			qDebug("CCONTAINER_arrange: (%s %s): move = %d  resize = %d  setGeometry = %d", GB.GetClassName(THIS), THIS->widget.name, _count_move, _count_resize, _count_set_geom);
-	}
+	}*/
 	#endif
 }
 
@@ -472,7 +505,10 @@ void CCONTAINER_insert_child(void *_object)
 {
 	CWIDGET *parent = CWidget::get(WIDGET->parentWidget());
 	if (parent)
+	{
+		CCONTAINER_update_design(parent);
 		GB.Raise(parent, EVENT_Insert, 1, GB_T_OBJECT, THIS);
+	}
 }
 
 void CCONTAINER_decide(CWIDGET *control, bool *width, bool *height)
@@ -481,20 +517,97 @@ void CCONTAINER_decide(CWIDGET *control, bool *width, bool *height)
 
 	*width = *height = FALSE;
 	
-	if (!THIS || control->flag.ignore || THIS_ARRANGEMENT->autoresize)
+	if (!THIS || !control->flag.resized || control->flag.ignore || THIS_ARRANGEMENT->autoresize)
 		return;
 	
 	if ((THIS_ARRANGEMENT->mode == ARRANGE_VERTICAL)
 	    || (THIS_ARRANGEMENT->mode == ARRANGE_HORIZONTAL && control->flag.expand)
-	    || (THIS_ARRANGEMENT->mode == ARRANGE_ROW && control->flag.expand))
+	    || (THIS_ARRANGEMENT->mode == ARRANGE_ROW && control->flag.expand)
+			|| (THIS_ARRANGEMENT->mode == ARRANGE_FILL))
 		*width = TRUE;
 	
 	if ((THIS_ARRANGEMENT->mode == ARRANGE_HORIZONTAL)
 	    || (THIS_ARRANGEMENT->mode == ARRANGE_VERTICAL && control->flag.expand)
-	    || (THIS_ARRANGEMENT->mode == ARRANGE_COLUMN && control->flag.expand))
+	    || (THIS_ARRANGEMENT->mode == ARRANGE_COLUMN && control->flag.expand)
+			|| (THIS_ARRANGEMENT->mode == ARRANGE_FILL))
 		*height = TRUE;
 }
 
+void CCONTAINER_update_design(void *_object)
+{
+	QObjectList list;
+	CWIDGET *child;
+	int i;
+
+	if (!THIS->widget.flag.design)
+		return;
+	
+	if (!THIS->widget.flag.user && !THIS->widget.flag.design_ignore)
+		return;
+	
+	//fprintf(stderr, "CCONTAINER_update_design: %s %d\n", THIS->widget.name, THIS->widget.flag.design_ignore);
+	
+	if (THIS->widget.flag.design_ignore)
+	{
+		list = THIS->widget.widget->children();
+		
+		for (i = 0; i < list.count(); i++)
+		{
+			child = CWidget::getRealExisting(list.at(i));
+			if (child)
+				CWIDGET_set_design(child, true);
+		}
+	}
+
+	if (GB.Is(THIS, CLASS_UserContainer) && CONTAINER == WIDGET)
+		return;
+	
+	list = CONTAINER->children();
+	
+	for (i = 0; i < list.count(); i++)
+	{
+		child = CWidget::getRealExisting(list.at(i));
+		if (child)
+			CWIDGET_set_design(child, true);
+	}
+}
+
+void *CCONTAINER_get_first_child(void *_object)
+{
+	if (!GB.Is(THIS, CLASS_Container))
+		return NULL;
+	
+	QObjectList list = GB.Is(THIS, CLASS_Window) ? CONTAINER->children() : WIDGET->children();
+	void *ob;
+	
+	for (int i = 0; i < list.count(); i++)
+	{
+		ob = CWidget::getRealExisting(list.at(i));
+		if (ob)
+			return ob;
+	}
+
+	return NULL;
+}
+
+void *CCONTAINER_get_last_child(void *_object)
+{
+	if (!GB.Is(THIS, CLASS_Container))
+		return NULL;
+
+	QObjectList list = GB.Is(THIS, CLASS_Window) ? CONTAINER->children() : WIDGET->children();
+	void *ob;
+			
+	for (int i = list.count() - 1; i >= 0; i--)
+	{
+		ob = CWidget::getRealExisting(list.at(i));
+		if (ob)
+			return ob;
+	}
+	
+	return NULL;
+}
+
 
 /***************************************************************************
 
@@ -543,6 +656,8 @@ static void _draw_border(QPainter *p, int frame, QWidget *w, QStyleOptionFrame &
 	else
 		style = QApplication::style();
 
+	p->save();
+	
 	switch (frame)
 	{
 		case BORDER_PLAIN:
@@ -567,18 +682,17 @@ static void _draw_border(QPainter *p, int frame, QWidget *w, QStyleOptionFrame &
 			p->setBrush(QBrush());
 			style->drawPrimitive(QStyle::PE_Frame, &optv3, p, w);
 			p->setBrush(save_brush);
-			//style->drawControl(QStyle::CE_ShapedFrame, &optv3, p, w);
 			break;
 			
 		case BORDER_RAISED:
 			optv3.rect = opt.rect;
 			optv3.state = opt.state | QStyle::State_Raised;
 			optv3.frameShape = QFrame::StyledPanel;
+
+			save_brush = p->brush();
+			p->setBrush(QBrush());
 			style->drawPrimitive(QStyle::PE_Frame, &optv3, p, w);
-			/*opt.lineWidth = 2;
-			opt.midLineWidth = 2;
-			opt.state |= QStyle::State_Raised;
-			style->drawPrimitive(QStyle::PE_Frame, &opt, p, w);*/
+			p->setBrush(save_brush);
 			break;
 			
 		case BORDER_ETCHED:
@@ -586,12 +700,10 @@ static void _draw_border(QPainter *p, int frame, QWidget *w, QStyleOptionFrame &
 			//optv3.state = opt.state | QStyle::State_Raised;
 			optv3.frameShape = QFrame::StyledPanel;
 			style->drawPrimitive(QStyle::PE_FrameGroupBox, &optv3, p, w);
-			//qDrawShadeRect(p, opt.rect, opt.palette, true, 1, 0);
 			break;
-			
-		default:
-			return;
 	}
+	
+	p->restore();
 }
 
 void CCONTAINER_draw_border(QPainter *p, char frame, QWidget *wid)
@@ -713,7 +825,7 @@ MyContainer::~MyContainer()
 {
 	CWIDGET *_object = CWidget::getReal(this);
 	if (THIS)
-		CWIDGET_set_flag(THIS, WF_DELETED);
+		THIS->widget.flag.deleted = true;
 }
 
 void MyContainer::showEvent(QShowEvent *e)
@@ -741,51 +853,71 @@ void MyContainer::hideEvent(QHideEvent *e)
 	}*/
 }
 
-
-
-/*void MyContainer::childEvent(QChildEvent *e)
+static void cleanup_drawing(intptr_t arg1, intptr_t arg2)
 {
-	//void *_object = CWidget::get(this);
-	void *child;
-	//qDebug("MyContainer::childEvent %p", CWidget::get(this));
+	PAINT_end();
+}
+
+void MyContainer::paintEvent(QPaintEvent *event)
+{
+	void *_object = CWidget::get(this);
+	QRect r;
+	GB_ERROR_HANDLER handler;
 	
-	QFrame::childEvent(e);
-
-	if (!e->child()->isWidgetType())
+	if (!THIS->widget.flag.user)
+	{
+		MyFrame::paintEvent(event);
 		return;
-
-	child = CWidget::get((QWidget *)e->child());
-
-	if (e->added())
-	{
-		//e->child()->installEventFilter(this);
-		//qApp->sendEvent(WIDGET, new QEvent(EVENT_INSERT));
-		//if (THIS_ARRANGEMENT->user)
-		//	GB.Raise(THIS, EVENT_Insert, 1, GB_T_OBJECT, child);    
 	}
-	else if (e->removed())
+	
+	if (THIS_USERCONTROL->func.paint)
 	{
-		//e->child()->removeEventFilter(this);
-		//if (THIS_ARRANGEMENT->user)
-		//	GB.Raise(THIS, EVENT_Remove, 1, GB_T_OBJECT, child);
+		r = event->rect();
+
+		PAINT_begin(THIS);
+
+		//fprintf(stderr, "paintEvent: %s: %d %d %d %d\n", THIS->widget.name, r.x(), r.y(), r.width(), r.height());
+		PAINT_clip(r.x(), r.y(), r.width(), r.height());
+
+		handler.handler = (GB_CALLBACK)cleanup_drawing;
+
+		GB.OnErrorBegin(&handler);
+		CALL_FUNCTION(THIS_USERCONTROL, paint);
+		GB.OnErrorEnd(&handler);
+
+		PAINT_end();
 	}
+}
 
-	arrange_later(this);
-}*/
-
-/*bool MyContainer::eventFilter(QObject *o, QEvent *e)
+void MyContainer::changeEvent(QEvent *e)
 {
-	int type = e->type();
+	void *_object = CWidget::get(this);
 
-	if (type == QEvent::Move || type == QEvent::Resize || type == QEvent::Show || type == QEvent::Hide || type == EVENT_EXPAND)
+	if (e->type() == QEvent::LayoutDirectionChange)
+		CCONTAINER_arrange(THIS);
+	
+	if (!THIS->widget.flag.user)
 	{
-		CWIDGET *ob = CWidget::getReal(o);
-		if (ob && (type == EVENT_EXPAND || !ob->flag.ignore))
-			arrange_now(this);
+		MyFrame::changeEvent(e);
+		return;
 	}
+	
+	if (e->type() == QEvent::FontChange)
+	{
+		CALL_FUNCTION(THIS_USERCONTROL, font);
+	}
+	else if (e->type() == QEvent::EnabledChange)
+	{
+		update();
+	}
+}
 
-	return QObject::eventFilter(o, e);
-}*/
+void MyContainer::resizeEvent(QResizeEvent *e)
+{
+	void *_object = CWidget::get(this);
+	if (THIS->widget.flag.user)
+		CALL_FUNCTION(THIS_USERCONTROL, resize);
+}
 
 
 /***************************************************************************
@@ -807,7 +939,7 @@ static QRect getRect(void *_object)
 	return w->contentsRect();
 }
 
-BEGIN_PROPERTY(Container_X)
+BEGIN_PROPERTY(Container_ClientX)
 
 	#ifdef DEBUG
 	if (!CONTAINER)
@@ -822,7 +954,7 @@ BEGIN_PROPERTY(Container_X)
 END_PROPERTY
 
 
-BEGIN_PROPERTY(Container_Y)
+BEGIN_PROPERTY(Container_ClientY)
 
 	#ifdef DEBUG
 	if (!CONTAINER)
@@ -837,7 +969,7 @@ BEGIN_PROPERTY(Container_Y)
 END_PROPERTY
 
 
-BEGIN_PROPERTY(Container_Width)
+BEGIN_PROPERTY(Container_ClientWidth)
 
 	#ifdef DEBUG
 	if (!CONTAINER)
@@ -849,7 +981,7 @@ BEGIN_PROPERTY(Container_Width)
 END_PROPERTY
 
 
-BEGIN_PROPERTY(Container_Height)
+BEGIN_PROPERTY(Container_ClientHeight)
 
 	#ifdef DEBUG
 	if (!CONTAINER)
@@ -921,7 +1053,7 @@ BEGIN_PROPERTY(UserContainer_Arrangement)
 
 END_PROPERTY
 
-BEGIN_PROPERTY(UserContainer_Focus)
+BEGIN_PROPERTY(UserControl_Focus)
 
 	if (READ_PROPERTY)
 		GB.ReturnBoolean(CWIDGET_get_allow_focus(THIS));
@@ -1074,12 +1206,11 @@ END_PROPERTY
 BEGIN_PROPERTY(Container_Indent)
 
   if (READ_PROPERTY)
-    GB.ReturnInteger(THIS_ARRANGEMENT->indent);
+    GB.ReturnBoolean(THIS_ARRANGEMENT->indent);
   else
   {
-  	int val = VPROP(GB_INTEGER);
-		if (val < 0) val = 1;
-  	if (val != THIS_ARRANGEMENT->indent && val >= 0 && val <= 7)
+  	bool val = VPROP(GB_BOOLEAN);
+  	if (val != THIS_ARRANGEMENT->indent)
   	{
     	THIS_ARRANGEMENT->indent = val;
 			arrange_now(CONTAINER);
@@ -1088,19 +1219,51 @@ BEGIN_PROPERTY(Container_Indent)
 
 END_PROPERTY
 
+BEGIN_PROPERTY(Container_Centered)
+
+  if (READ_PROPERTY)
+    GB.ReturnBoolean(THIS_ARRANGEMENT->centered);
+  else
+  {
+  	bool val = VPROP(GB_BOOLEAN);
+  	if (val != THIS_ARRANGEMENT->centered)
+  	{
+    	THIS_ARRANGEMENT->centered = val;
+			arrange_now(CONTAINER);
+		}
+  }
+
+END_PROPERTY
+
+static void declare_special_event_handler(void *_object, ushort *index, const char *suffix)
+{
+	GB_FUNCTION func;
+	char name[128];
+
+	snprintf(name, sizeof(name), "%s_%s", GB.Is(THIS, CLASS_UserContainer) ? "UserContainer" : "UserControl", suffix);
+	if (!GB.GetFunction(&func, THIS, name, NULL, NULL))
+		*index = func.index;
+}
+
 BEGIN_METHOD(UserControl_new, GB_OBJECT parent)
 
 	MyContainer *wid = new MyContainer(QCONTAINER(VARG(parent)));
 
+	THIS->widget.flag.user = true;
 	THIS->container = wid;
 	THIS_ARRANGEMENT->mode = ARRANGE_FILL;
-	THIS_ARRANGEMENT->user = true;
 
 	CWIDGET_new(wid, (void *)_object);
+	
+	declare_special_event_handler(THIS, &THIS_USERCONTROL->func.paint, "Draw");
+	declare_special_event_handler(THIS, &THIS_USERCONTROL->func.font, "Font");
+	declare_special_event_handler(THIS, &THIS_USERCONTROL->func.change, "Change");
+	declare_special_event_handler(THIS, &THIS_USERCONTROL->func.resize, "Resize");
 
+	GB.Error(NULL);
+	
 END_METHOD
 
-
 BEGIN_PROPERTY(UserControl_Container)
 
 	void *current = (CCONTAINER *)CWidget::get(CONTAINER);
@@ -1122,6 +1285,7 @@ BEGIN_PROPERTY(UserControl_Container)
 			if (current)
 				CWIDGET_container_for(current, NULL);
 			THIS->container = WIDGET;
+			CCONTAINER_update_design(THIS);
 			CWIDGET_register_proxy(THIS, NULL);
 			return;
 		}
@@ -1140,25 +1304,27 @@ BEGIN_PROPERTY(UserControl_Container)
 		}
 
 		if (!p)
-			GB.Error("Container must be a child control");
-		else
 		{
-			GB_COLOR bg = CWIDGET_get_background((CWIDGET *)current, true);
-			GB_COLOR fg = CWIDGET_get_foreground((CWIDGET *)current, true);
-
-			if (current)
-				CWIDGET_container_for(current, NULL);
-			CWIDGET_container_for(cont, THIS);
-			
-			THIS->container = w;
-
-			CWIDGET_update_design((CWIDGET *)THIS);
-			CCONTAINER_arrange(THIS);
-
-			CWIDGET_set_color((CWIDGET *)cont, bg, fg, true);
-
-			CWIDGET_register_proxy(THIS, cont);
+			GB.Error("Container must be a child control");
+			return;
 		}
+		
+		GB_COLOR bg = CWIDGET_get_background((CWIDGET *)current, true);
+		GB_COLOR fg = CWIDGET_get_foreground((CWIDGET *)current, true);
+
+		if (current)
+			CWIDGET_container_for(current, NULL);
+		CWIDGET_container_for(cont, THIS);
+		
+		THIS->container = w;
+
+		CCONTAINER_arrange(THIS);
+
+		CWIDGET_set_color((CWIDGET *)cont, bg, fg, true);
+		
+		CCONTAINER_update_design(THIS);
+
+		CWIDGET_register_proxy(THIS, cont);
 	}
 
 END_PROPERTY
@@ -1169,9 +1335,17 @@ BEGIN_PROPERTY(UserContainer_Indent)
 	CCONTAINER *cont = (CCONTAINER *)CWidget::get(CONTAINER);
 	Container_Indent(cont, _param);
 	if (!READ_PROPERTY)
-	{
 		THIS_USERCONTAINER->save = cont->arrangement;
-	}
+
+END_PROPERTY
+
+
+BEGIN_PROPERTY(UserContainer_Centered)
+
+	CCONTAINER *cont = (CCONTAINER *)CWidget::get(CONTAINER);
+	Container_Centered(cont, _param);
+	if (!READ_PROPERTY)
+		THIS_USERCONTAINER->save = cont->arrangement;
 
 END_PROPERTY
 
@@ -1207,7 +1381,6 @@ BEGIN_PROPERTY(UserContainer_Design)
 		CCONTAINER *cont = (CCONTAINER *)CWidget::get(CONTAINER);
 		
 		cont->arrangement = 0;
-		((CCONTAINER_ARRANGEMENT *)cont)->user = true;
 		THIS_USERCONTAINER->save = cont->arrangement;
 	}
 
@@ -1411,12 +1584,12 @@ GB_DESC ContainerDesc[] =
 
 	GB_PROPERTY_READ("Children", "ContainerChildren", Container_Children),
 
-	GB_PROPERTY_READ("ClientX", "i", Container_X),
-	GB_PROPERTY_READ("ClientY", "i", Container_Y),
-	GB_PROPERTY_READ("ClientW", "i", Container_Width),
-	GB_PROPERTY_READ("ClientWidth", "i", Container_Width),
-	GB_PROPERTY_READ("ClientH", "i", Container_Height),
-	GB_PROPERTY_READ("ClientHeight", "i", Container_Height),
+	GB_PROPERTY_READ("ClientX", "i", Container_ClientX),
+	GB_PROPERTY_READ("ClientY", "i", Container_ClientY),
+	GB_PROPERTY_READ("ClientW", "i", Container_ClientWidth),
+	GB_PROPERTY_READ("ClientWidth", "i", Container_ClientWidth),
+	GB_PROPERTY_READ("ClientH", "i", Container_ClientHeight),
+	GB_PROPERTY_READ("ClientHeight", "i", Container_ClientHeight),
 	
 	GB_METHOD("_unknown", "v", Container_unknown, "."),
 	GB_METHOD("FindChild", "Control", Container_FindChild, "(X)i(Y)i"),
@@ -1433,7 +1606,7 @@ GB_DESC ContainerDesc[] =
 
 GB_DESC UserControlDesc[] =
 {
-	GB_DECLARE("UserControl", sizeof(CCONTAINER)), GB_INHERITS("Container"),
+	GB_DECLARE("UserControl", sizeof(CUSERCONTROL)), GB_INHERITS("Container"),
 	GB_NOT_CREATABLE(),
 
 	GB_METHOD("_new", NULL, UserControl_new, "(Parent)Container;"),
@@ -1446,9 +1619,13 @@ GB_DESC UserControlDesc[] =
 	GB_PROPERTY("_Margin", "b", Container_Margin),
 	GB_PROPERTY("_Indent", "b", Container_Indent),
 	GB_PROPERTY("_Invert", "b", Container_Invert),
+	GB_PROPERTY("_Centered", "b", Container_Centered),
+	GB_PROPERTY("_Focus", "b", UserControl_Focus),
 
 	USERCONTROL_DESCRIPTION,
 	
+	GB_INTERFACE("Paint", &PAINT_Interface),
+
 	GB_END_DECLARE
 };
 
@@ -1470,11 +1647,14 @@ GB_DESC UserContainerDesc[] =
 	GB_PROPERTY("Margin", "b", UserContainer_Margin),
 	GB_PROPERTY("Indent", "b", UserContainer_Indent),
 	GB_PROPERTY("Invert", "b", UserContainer_Invert),
-	
+	GB_PROPERTY("Centered", "b", UserContainer_Centered),
+
 	GB_PROPERTY("Design", "b", UserContainer_Design),
 
 	//GB_PROPERTY("Focus", "b", UserContainer_Focus),
 
+	GB_INTERFACE("Paint", &PAINT_Interface),
+
 	USERCONTAINER_DESCRIPTION,
 	
 	GB_END_DECLARE
