@@ -2,7 +2,7 @@
 
 	CMenu.cpp
 
-	(c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
+	(c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -170,14 +170,6 @@ static void unregister_menu(CMENU *_object)
 	}
 }
 
-static void set_menu_visible(void *_object, bool v)
-{
-	THIS->visible = v;
-	ACTION->setVisible(v);
-	refresh_menubar(THIS);
-	//update_accel_recursive(THIS);
-}
-
 static void delete_menu(CMENU *_object)
 {
 	if (THIS->deleted)
@@ -245,7 +237,7 @@ static bool is_fully_enabled(CMENU *_object)
 		if (THIS->exec)
 			return true;
 
-		if (THIS->disabled)
+		if (THIS->disabled || !THIS->visible)
 			return false;
 
 		if (CMENU_is_toplevel(THIS))
@@ -276,8 +268,8 @@ static void update_accel(CMENU *_object)
 
 static void update_accel_recursive(CMENU *_object)
 {
-	if (THIS->exec)
-		return;
+	/*if (THIS->exec)
+		return;*/
 
 	update_accel(THIS);
 
@@ -290,6 +282,14 @@ static void update_accel_recursive(CMENU *_object)
 	}
 }
 
+static void set_menu_visible(void *_object, bool v)
+{
+	THIS->visible = v;
+	ACTION->setVisible(v);
+	refresh_menubar(THIS);
+	update_accel_recursive(THIS);
+}
+
 static void update_check(CMENU *_object)
 {
 	if (THIS->checked || THIS->toggle || THIS->radio)
@@ -547,9 +547,13 @@ BEGIN_PROPERTY(Menu_Picture)
 		QIcon icon;
 
 		GB.StoreObject(PROP(GB_OBJECT), POINTER(&(THIS->picture)));
-		if (THIS->picture)
-			icon = QIcon(*THIS->picture->pixmap);
-		ACTION->setIcon(icon);
+
+		if (!CMENU_is_toplevel(THIS))
+		{
+			if (THIS->picture)
+				icon = QIcon(*THIS->picture->pixmap);
+			ACTION->setIcon(icon);
+		}
 	}
 
 END_PROPERTY
@@ -757,26 +761,21 @@ END_METHOD
 
 void CMENU_popup(CMENU *_object, const QPoint &pos)
 {
-	bool disabled;
 	void *save;
 
 	HANDLE_PROXY(_object);
 	
 	if (THIS->menu && !THIS->exec)
 	{
-		disabled = THIS->disabled;
-		if (disabled)
-		{
-			THIS->disabled = false;
-			update_accel_recursive(THIS);
-			THIS->disabled = true;
-		}
-
 		//qDebug("CMENU_popup: %p: open", THIS);
 
 		// The Click event is posted, it does not occur immediately.
 		save = CWIDGET_enter_popup();
 		THIS->exec = true;
+
+		update_accel_recursive(THIS);
+
+		//update_accel_recursive(THIS);
 		_popup_immediate = true;
 		THIS->menu->exec(pos);
 		_popup_immediate = false;
@@ -834,6 +833,15 @@ BEGIN_PROPERTY(Menu_Window)
 
 END_PROPERTY
 
+BEGIN_PROPERTY(Menu_Parent)
+
+	if (CMENU_is_toplevel(THIS))
+		GB.ReturnNull();
+	else
+		GB.ReturnObject(THIS->parent);
+
+END_PROPERTY
+
 BEGIN_PROPERTY(Menu_Action)
 
 	char *current = THIS_EXT ? THIS_EXT->action : NULL;
@@ -944,6 +952,7 @@ GB_DESC CMenuDesc[] =
 	GB_PROPERTY("Radio", "b", Menu_Radio),
 	GB_PROPERTY("Value", "b", Menu_Value),
 	GB_PROPERTY("Action", "s", Menu_Action),
+	GB_PROPERTY_READ("Parent", "Menu", Menu_Parent),
 	GB_PROPERTY_READ("Window", "Window", Menu_Window),
 	GB_PROPERTY("Proxy", "Menu", Menu_Proxy),
 
@@ -1247,6 +1256,7 @@ void MyMenu::setVisible(bool visible)
 void CMENU_update_menubar(CWINDOW *window)
 {
 	static bool init = FALSE;
+	static bool norec = FALSE;
 
 	if (!init)
 	{
@@ -1254,7 +1264,12 @@ void CMENU_update_menubar(CWINDOW *window)
 		init = TRUE;
 	}
 
+	if (norec)
+		return;
+
+	norec = TRUE;
 	GB.Push(1, GB_T_OBJECT, window);
 	GB.Call(&_init_menubar_shortcut_func, 1, FALSE);
+	norec = FALSE;
 }
 
