@@ -2,7 +2,7 @@
 
   CScreen.cpp
 
-  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -48,8 +48,6 @@
 #include "x11.h"
 #endif
 
-#include "desktop.h"
-
 #ifdef QT5
 	#define DESKTOP_INFO() (QGuiApplication::screens().front()->availableGeometry())
 	#define SCREEN_INFO(_id) (QGuiApplication::screens().at(_id)->geometry())
@@ -76,6 +74,7 @@ static CSCREEN *_screens[MAX_SCREEN] = { NULL };
 
 static bool _animations = FALSE;
 static bool _shadows = FALSE;
+static bool _middle_click_paste = TRUE;
 
 static CSCREEN *get_screen(int num)
 {
@@ -176,12 +175,6 @@ BEGIN_PROPERTY(Desktop_Scale)
 
 END_PROPERTY
 
-BEGIN_PROPERTY(Desktop_Type)
-
-	GB.ReturnConstZeroString(DESKTOP_get_type());
-
-END_PROPERTY
-
 BEGIN_PROPERTY(Desktop_Platform)
 
 	GB.ReturnConstZeroString(MAIN_platform);
@@ -284,6 +277,16 @@ BEGIN_PROPERTY(Application_Animations)
 END_PROPERTY
 
 
+BEGIN_PROPERTY(Application_MiddleClickPaste)
+
+	if (READ_PROPERTY)
+		GB.ReturnBoolean(_middle_click_paste);
+	else
+		_middle_click_paste = VPROP(GB_BOOLEAN);
+
+END_PROPERTY
+
+
 BEGIN_PROPERTY(Application_Shadows)
 
 	if (READ_PROPERTY)
@@ -564,7 +567,6 @@ GB_DESC DesktopDesc[] =
 	
 	GB_STATIC_METHOD("Screenshot", "Picture", Desktop_Screenshot, "[(X)i(Y)i(Width)i(Height)i]"),
 	
-	GB_STATIC_PROPERTY_READ("Type", "s", Desktop_Type),
 	GB_STATIC_PROPERTY_READ("Platform", "s", Desktop_Platform),
 
 	GB_END_DECLARE
@@ -583,6 +585,7 @@ GB_DESC ApplicationDesc[] =
 	GB_STATIC_PROPERTY("Busy", "i", Application_Busy),
 	GB_STATIC_PROPERTY("ShowTooltips", "b", Application_ShowTooltips),
 	GB_STATIC_PROPERTY("Animations", "b", Application_Animations),
+	GB_STATIC_PROPERTY("MiddleClickPaste", "b", Application_MiddleClickPaste),
 	GB_STATIC_PROPERTY("Shadows", "b", Application_Shadows),
 	GB_STATIC_PROPERTY("Embedder", "i", Application_Embedder),
 	GB_STATIC_PROPERTY("Theme", "s", Application_Theme),
