@@ -2,7 +2,7 @@
 
   CWidget.h
 
-  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
+  (c) 2000-2017 Benoît Minisini <benoit.minisini@gambas-basic.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,8 +44,8 @@ typedef
 		void *proxy;
 		void *proxy_for;
 		char *action;
-		int focusPolicy;
 		void *container_for;
+		char mouse;
 	}
 	CWIDGET_EXT;
 
@@ -70,7 +70,7 @@ typedef
 			unsigned old_tracking : 1;
 			unsigned grab : 1;
 			unsigned dragging: 1;
-			unsigned noTabFocus : 1;
+			unsigned no_tab_focus : 1;
 			unsigned inside : 1;
 
 			unsigned inside_later : 1;
@@ -87,6 +87,8 @@ typedef
 			unsigned no_design : 1;
 			unsigned orientation : 1;          // for scrollbars & similar widgets
 			unsigned inverted : 1;             // if layout has been inverted
+			unsigned direction : 2;            // text direction
+			unsigned user : 1;                 // UserControl or UserContainer
 			} flag;
 		char *name;
 		void *font;
@@ -101,18 +103,16 @@ typedef
 		CWIDGET widget;
 		QWidget *container;
 		unsigned mode : 4;
-		unsigned user : 1;
 		unsigned locked : 1;
+		unsigned dirty : 1;
 		unsigned margin : 1;
 		unsigned spacing : 1;
 		unsigned padding : 8;
 		unsigned indent : 1;
 		unsigned centered : 1;
-		unsigned dirty : 1;
 		unsigned autoresize : 1;
 		unsigned invert : 1;
-		unsigned paint : 1;
-		unsigned _reserved: 10;
+		unsigned _reserved: 12;
 		}
 	CCONTAINER_ARRANGEMENT;
 
@@ -261,6 +261,7 @@ void *CWIDGET_get_next_previous(void *_object, bool next);
 void CWIDGET_set_focus(void *_object);
 void *CWIDGET_get_next_focus(void *_object);
 void *CWIDGET_get_previous_focus(void *_object);
+bool CWIDGET_has_no_tab_focus(void *_object);
 
 #ifndef DO_NOT_DECLARE_EVENTS
 #ifndef __CWIDGET_CPP
