@@ -658,16 +658,16 @@ void WATCH_wait(int wait)
 	struct timeval *now;
 	struct timeval timeout;
 
-	if (wait == 0)
+	if (wait == -2)
+	{
+		do_loop(NULL);
+	}
+	else if (wait <= 0)
 	{
 		timeout.tv_sec = 0;
 		timeout.tv_usec = 0;
 		do_loop(&timeout);
 	}
-	else if (wait < 0)
-	{
-		do_loop(NULL);
-	}
 	else
 	{
 		now = time_now();
